@@ -279,7 +279,7 @@ soup_connection_class_init (SoupConnectionClass *connection_class)
 /**
  * soup_connection_new:
  * @propname1: name of first property to set
- * @...:
+ * @...: value of @propname1, followed by additional property/value pairs
  *
  * Creates an HTTP connection. You must set at least one of
  * %SOUP_CONNECTION_ORIGIN_URI or %SOUP_CONNECTION_PROXY_URI. If you
@@ -555,6 +555,7 @@ soup_connection_connect_async (SoupConnection *conn,
 			       gpointer user_data)
 {
 	SoupConnectionPrivate *priv;
+	SoupAddress *addr;
 
 	g_return_if_fail (SOUP_IS_CONNECTION (conn));
 	priv = SOUP_CONNECTION_GET_PRIVATE (conn);
@@ -565,16 +566,19 @@ soup_connection_connect_async (SoupConnection *conn,
 					  G_CALLBACK (callback), user_data);
 	}
 
+	addr = soup_address_new (priv->conn_uri->host, priv->conn_uri->port);
+
 	priv->socket =
 		soup_socket_new (SOUP_SOCKET_SSL_CREDENTIALS, priv->ssl_creds,
 				 SOUP_SOCKET_ASYNC_CONTEXT, priv->async_context,
 				 NULL);
-	soup_socket_connect (priv->socket, soup_address_new (priv->conn_uri->host,
-							     priv->conn_uri->port));
+	soup_socket_connect (priv->socket, addr);
 	soup_signal_connect_once (priv->socket, "connect_result",
 				  G_CALLBACK (socket_connect_result), conn);
 	g_signal_connect (priv->socket, "disconnected",
 			  G_CALLBACK (socket_disconnected), conn);
+
+	g_object_unref (addr);
 }
 
 /**
