@@ -57,10 +57,10 @@
 /* NONE:OBJECT,STRING,STRING,POINTER,POINTER (./soup-marshal.list:4) */
 void
 soup_marshal_VOID__OBJECT_STRING_STRING_POINTER_POINTER (GClosure     *closure,
-                                                         GValue       *return_value,
+                                                         GValue       *return_value G_GNUC_UNUSED,
                                                          guint         n_param_values,
                                                          const GValue *param_values,
-                                                         gpointer      invocation_hint,
+                                                         gpointer      invocation_hint G_GNUC_UNUSED,
                                                          gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_STRING_STRING_POINTER_POINTER) (gpointer     data1,
