@@ -7,8 +7,12 @@
 #define SOUP_MISC_H 1
 
 #include <glib-object.h>
+#include <libxml/tree.h>
 
-/* Base64 encoding/decoding */
+G_BEGIN_DECLS
+
+#ifndef LIBSOUP_DISABLE_DEPRECATED
+/* Base64 encoding/decoding. DEPRECATED: use <glib/base64.h> */
 
 char              *soup_base64_encode        (const char   *text,
 					      int           len);
@@ -35,6 +39,7 @@ int                soup_base64_decode_step   (const guchar *in,
 					      guchar       *out, 
 					      int          *state, 
 					      guint        *save);
+#endif /* LIBSOUP_DISABLE_DEPRECATED */
 
 /* Non-default-GMainContext operations */
 GSource           *soup_add_io_watch         (GMainContext *async_context,
@@ -61,6 +66,8 @@ guint              soup_str_case_hash        (gconstpointer key);
 gboolean           soup_str_case_equal       (gconstpointer v1,
 					      gconstpointer v2);
 
+xmlNode           *soup_xml_real_node        (xmlNode      *node);
+
 /**
  * soup_ssl_supported:
  *
@@ -68,4 +75,6 @@ gboolean           soup_str_case_equal       (gconstpointer v1,
  **/
 extern gboolean soup_ssl_supported;
 
+G_END_DECLS
+
 #endif /* SOUP_MISC_H */
