@@ -9,42 +9,56 @@
 #include <config.h>
 #endif
 
-#ifndef HAVE_SSL
-
 #include "soup-ssl.h"
 #include "soup-misc.h"
 
+#ifndef HAVE_SSL
+
 gboolean soup_ssl_supported = FALSE;
 
 GIOChannel *
 soup_ssl_wrap_iochannel (GIOChannel *sock, SoupSSLType type,
-			 const char *hostname, gpointer cred_pointer)
+			 const char *hostname, SoupSSLCredentials *creds)
 {
 	return NULL;
 }
 
-gpointer
+SoupSSLCredentials *
 soup_ssl_get_client_credentials (const char *ca_file)
 {
 	return NULL;
 }
 
 void
-soup_ssl_free_client_credentials (gpointer client_creds)
+soup_ssl_free_client_credentials (SoupSSLCredentials *client_creds)
 {
 	;
 }
 
-gpointer
+SoupSSLCredentials *
 soup_ssl_get_server_credentials (const char *cert_file, const char *key_file)
 {
 	return NULL;
 }
 
 void
-soup_ssl_free_server_credentials (gpointer server_creds)
+soup_ssl_free_server_credentials (SoupSSLCredentials *server_creds)
 {
 	;
 }
 
 #endif /* ! HAVE_SSL */
+
+/**
+ * soup_ssl_error_quark:
+ *
+ * Return value: The quark used as %SOUP_SSL_ERROR
+ **/
+GQuark
+soup_ssl_error_quark (void)
+{
+	static GQuark error;
+	if (!error)
+		error = g_quark_from_static_string ("soup_ssl_error_quark");
+	return error;
+}
