@@ -9,6 +9,8 @@
 #include <libsoup/soup-types.h>
 #include <libsoup/soup-session.h>
 
+G_BEGIN_DECLS
+
 #define SOUP_TYPE_SESSION_ASYNC            (soup_session_async_get_type ())
 #define SOUP_SESSION_ASYNC(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), SOUP_TYPE_SESSION_ASYNC, SoupSessionAsync))
 #define SOUP_SESSION_ASYNC_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), SOUP_TYPE_SESSION_ASYNC, SoupSessionAsyncClass))
@@ -32,5 +34,6 @@ SoupSession *soup_session_async_new              (void);
 SoupSession *soup_session_async_new_with_options (const char *optname1,
 						  ...) G_GNUC_NULL_TERMINATED;
 
+G_END_DECLS
 
 #endif /* SOUP_SESSION_ASYNC_H */
